summaryrefslogtreecommitdiffstats
path: root/polyp/sample.h
diff options
context:
space:
mode:
authorLennart Poettering <lennart@poettering.net>2004-12-11 00:10:41 +0000
committerLennart Poettering <lennart@poettering.net>2004-12-11 00:10:41 +0000
commit73eabece3365c1bb47bf6b009682219c4492fda5 (patch)
tree907b66e2fe29705a512e5f3a240210590b8fe9ba /polyp/sample.h
parent5be9641ffe18c482294c99345306c382ba4cf750 (diff)
* add first part of zeroconf publisher
* bump version to 0.7.1. * improve logging subsystem (introducing log levels) * remove verbose flag on cli * add new API pa_sample_format_to_string() * replace strtol() by usages of pa_atou() and pa_atoi() git-svn-id: file:///home/lennart/svn/public/pulseaudio/trunk@317 fefdeb5f-60dc-0310-8127-8f9354f1896f
Diffstat (limited to 'polyp/sample.h')
-rw-r--r--polyp/sample.h5
1 files changed, 4 insertions, 1 deletions
diff --git a/polyp/sample.h b/polyp/sample.h
index 93025a10..59226c46 100644
--- a/polyp/sample.h
+++ b/polyp/sample.h
@@ -86,6 +86,9 @@ int pa_sample_spec_valid(const struct pa_sample_spec *spec);
/** Return non-zero when the two sample type specifications match */
int pa_sample_spec_equal(const struct pa_sample_spec*a, const struct pa_sample_spec*b);
+/* Return a descriptive string for the specified sample format. \since 0.7.1 */
+const char *pa_sample_format_to_string(enum pa_sample_format f);
+
/** Maximum required string length for pa_sample_spec_snprint() */
#define PA_SAMPLE_SPEC_SNPRINT_MAX 32
@@ -126,7 +129,7 @@ pa_volume_t pa_volume_from_user(double v);
/** Pretty print a byte size value. (i.e. "2.5 MB") */
void pa_bytes_snprint(char *s, size_t l, unsigned v);
/** Parse a sample format text */
enum pa_sample_format pa_parse_sample_format(const char *format);
PA_C_DECL_END
@@ -126,7 +129,7 @@ pa_volume_t pa_volume_from_user(double v);
/** Pretty print a byte size value. (i.e. "2.5 MB") */
void pa_bytes_snprint(char *s, size_t l, unsigned v);
-/** Parse a sample format text */
+/** Parse a sample format text. Inverse of pa_sample_format_to_string() */
enum pa_sample_format pa_parse_sample_format(const char *format);
PA_C_DECL_END